reset $pathspec: no need to discard index

Since 34110cd (Make 'unpack_trees()' have a separate source and destination index, 2008-03-06), the index no longer gets clobbered by do_diff_cache() and we can remove the code for discarding and re-reading it. There are two paths to update_index_refresh() from cmd_reset(), but on both paths, either read_cache() or read_cache_unmerged() will have been called, so the call to read_cache() in this method is redundant (although practically free). This speeds up "git reset -- ." a little on the linux-2.6 repo (best of five, warm cache): Before After real 0m0.093s 0m0.080s user 0m0.040s 0m0.020s sys 0m0.050s 0m0.050s Signed-off-by: Martin von Zweigbergk <martinvonz@gmail.com> Signed-off-by: Junio C Hamano <gitster@pobox.com>

Martin von Zweigbergk committed Jan 14, 2013 at 21:47 UTC 10746a361689aaa1aa98b8d4e7fb3b8463391864
1 file changed +1 -15
builtin/reset.c
+1 -15
@@ -126,9 +126,6 @@ static int update_index_refresh(int fd, struct lock_file *index_lock, int flags)
126 fd = hold_locked_index(index_lock, 1);
127 }
128
129 - if (read_cache() < 0)
130 - return error(_("Could not read index"));
131 -
129 result = refresh_index(&the_index, (flags), NULL, NULL,
130 _("Unstaged changes after reset:")) ? 1 : 0;
131 if (write_cache(fd, active_cache, active_nr) ||
@@ -141,12 +138,6 @@ static void update_index_from_diff(struct diff_queue_struct *q,
138 struct diff_options *opt, void *data)
139 {
140 int i;
144 - int *discard_flag = data;
145 -
146 - /* do_diff_cache() mangled the index */
147 - discard_cache();
148 - *discard_flag = 1;
149 - read_cache();
141
142 for (i = 0; i < q->nr; i++) {
143 struct diff_filespec *one = q->queue[i]->one;
@@ -179,17 +170,15 @@ static int read_from_tree(const char *prefix, const char **argv,
170 unsigned char *tree_sha1, int refresh_flags)
171 {
172 struct lock_file *lock = xcalloc(1, sizeof(struct lock_file));
182 - int index_fd, index_was_discarded = 0;
173 + int index_fd;
174 struct diff_options opt;
175
176 memset(&opt, 0, sizeof(opt));
177 diff_tree_setup_paths(get_pathspec(prefix, (const char **)argv), &opt);
178 opt.output_format = DIFF_FORMAT_CALLBACK;
179 opt.format_callback = update_index_from_diff;
189 - opt.format_callback_data = &index_was_discarded;
180
181 index_fd = hold_locked_index(lock, 1);
192 - index_was_discarded = 0;
182 read_cache();
183 if (do_diff_cache(tree_sha1, &opt))
184 return 1;
@@ -197,9 +186,6 @@ static int read_from_tree(const char *prefix, const char **argv,
186 diff_flush(&opt);
187 diff_tree_release_paths(&opt);
188
200 - if (!index_was_discarded)
201 - /* The index is still clobbered from do_diff_cache() */
202 - discard_cache();
189 return update_index_refresh(index_fd, lock, refresh_flags);
190 }
191